# SubmitDataQueryRequestWarehouseSize

Specify the size of Zuora Warehouse. This field is available only if the sourceData is WAREHOUSE. If this field is not specified or set to NULL, the default value xsmall will be used. 

## Enum

* `XSMALL` (value: `'xsmall'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


